@@ -13,12 +13,13 @@ package Printer::ESCPOS;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 use 5.010;
-use Moose;
-use Moose::Util::TypeConstraints;
+use Moo;
+use Carp;
+use Type::Tiny;
 use aliased 'Printer::ESCPOS::Roles::Profile' => 'ESCPOSProfile';
 use namespace::autoclean;
 
@@ -30,7 +31,6 @@ use Printer::ESCPOS::Connections::USB;
 
 has driverType => (
     is       => 'ro',
-    isa      => enum( [qw[ File Network Serial USB ]] ),
     required => 1,
 );
 
@@ -41,42 +41,51 @@ has profile => (
 );
 
 
-has deviceFilePath => (
-    is  => 'ro',
-    isa => 'Str',
-);
+has deviceFilePath => ( is => 'ro', );
 
 
-has deviceIP => (
-    is  => 'ro',
-    isa => 'Str',
-);
+has deviceIP => ( is => 'ro', );
 
 
 has devicePort => (
     is      => 'ro',
-    isa     => 'Int',
     default => '9100',
 );
 
 
 has baudrate => (
     is      => 'ro',
-    isa     => 'Int',
     default => 38400,
 );
 
 
 has serialOverUSB => (
     is      => 'ro',
-    isa     => 'Bool',
     default => '1',
 );
 
+
+has vendorId => ( is => 'ro', );
+
+
+has productId => ( is => 'ro', );
+
+
+has endPoint => (
+    is      => 'ro',
+    default => 0x01,
+);
+
+
+has timeout => (
+    is       => 'ro',
+    required => 1,
+    default  => 1000,
+);
+
 has _driver => (
-    is         => 'ro',
-    lazy_build => 1,
-    init_arg   => undef,
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build__driver {
@@ -99,13 +108,18 @@ sub _build__driver {
             serialOverUSB  => $self->serialOverUSB,
         );
     }
+    elsif ( $self->driverType eq 'USB' ) {
+        return Printer::ESCPOS::Connections::USB->new(
+            productId => $self->productId,
+            vendorId  => $self->vendorId,
+            endPoint  => $self->endPoint,
+            timeout   => $self->timeout,
+        );
+    }
 }
 
 
-has printer => (
-    is         => 'ro',
-    lazy_build => 1,
-);
+has printer => ( is => 'lazy', );
 
 sub _build_printer {
     my ($self) = @_;
@@ -125,7 +139,7 @@ sub _build_printer {
     return $object;
 }
 
-no Moose;
+no Moo;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -140,7 +154,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -308,6 +322,22 @@ When used as a local serial device you can set the I<baudrate> of the printer to
 
 Set this value to 1 if you are connecting your printer using the USB Cable but it shows up as a serial device and you are using the B<Serial> driver.
 
+=head2 vendorId
+
+USB Printers VendorId. use lsusb command to get this value
+
+=head2 productId
+
+USB Printers product Id. use lsusb command to get this value
+
+=head2 endPoint
+
+USB endPoint to write to.
+
+=head2 timeout
+
+Timeout for bulk write functions for the USB printer.
+
 =head2 printer
 
 Use this attribute to send commands to the printer
