@@ -13,27 +13,23 @@ package Printer::ESCPOS::Connections::File;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 
 use 5.010;
-use Moose;
+use Moo;
 with 'Printer::ESCPOS::Roles::Connection';
 use namespace::autoclean;
 
 use IO::File;
 
 
-has deviceFilePath => (
-    is  => 'ro',
-    isa => 'Str',
-);
+has deviceFilePath => ( is => 'ro', );
 
 has _connection => (
-    is         => 'ro',
-    lazy_build => 1,
-    init_arg   => undef,
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build__connection {
@@ -45,7 +41,7 @@ sub _build__connection {
     return $printer;
 }
 
-no Moose;
+no Moo;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -60,7 +56,7 @@ Printer::ESCPOS::Connections::File - Bare Device File Connection Interface for L
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ATTRIBUTES
 
