@@ -13,34 +13,29 @@ package Printer::ESCPOS::Connections::Network;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 
 use 5.010;
-use Moose;
+use Moo;
 with 'Printer::ESCPOS::Roles::Connection';
 use namespace::autoclean;
 
 use IO::Socket;
 
 
-has deviceIP => (
-    is  => 'ro',
-    isa => 'Str',
-);
+has deviceIP => ( is => 'ro', );
 
 
 has devicePort => (
     is      => 'ro',
-    isa     => 'Int',
     default => '9100',
 );
 
 has _connection => (
-    is         => 'ro',
-    lazy_build => 1,
-    init_arg   => undef,
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build__connection {
@@ -70,7 +65,7 @@ sub read {
     return $data;
 }
 
-no Moose;
+no Moo;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -85,7 +80,7 @@ Printer::ESCPOS::Connections::Network - Network Connection Interface for L<Print
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ATTRIBUTES
 
