@@ -13,12 +13,12 @@ package Printer::ESCPOS::Connections::Serial;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 
 use 5.010;
-use Moose;
+use Moo;
 with 'Printer::ESCPOS::Roles::Connection';
 use namespace::autoclean;
 
@@ -26,36 +26,29 @@ use Device::SerialPort;
 use Time::HiRes qw(usleep);
 
 
-has deviceFilePath => (
-    is  => 'ro',
-    isa => 'Str',
-);
+has deviceFilePath => ( is => 'ro', );
 
 
 has baudrate => (
     is      => 'ro',
-    isa     => 'Int',
     default => 38400,
 );
 
 
 has readConstTime => (
     is      => 'ro',
-    isa     => 'Int',
     default => 150,
 );
 
 
 has serialOverUSB => (
     is      => 'rw',
-    isa     => 'Bool',
     default => '0',
 );
 
 has _connection => (
-    is         => 'ro',
-    lazy_build => 1,
-    init_arg   => undef,
+    is       => 'lazy',
+    init_arg => undef,
 );
 
 sub _build__connection {
@@ -92,7 +85,6 @@ sub print {
         $buffer = $raw;
     }
     else {
-        $buffer = $self->_buffer;
         $self->_buffer('');
     }
 
@@ -112,7 +104,7 @@ sub print {
     }
 }
 
-no Moose;
+no Moo;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -127,7 +119,7 @@ Printer::ESCPOS::Connections::Serial - Serial Connection Interface for L<Printer
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ATTRIBUTES
 
