@@ -13,11 +13,11 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 use 5.010;
-use Moose;
+use Moo;
 with 'Printer::ESCPOS::Roles::Profile';
 use namespace::autoclean;
 
@@ -465,7 +465,7 @@ sub inkStatusB {
 
 # END: Printer STATUS methods
 
-no Moose;
+no Moo;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -480,7 +480,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for L<Printer:
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 METHODS
 
