@@ -13,16 +13,16 @@ package Printer::ESCPOS::Profiles::SinocanPSeries;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 use 5.010;
-use Moose;
+use Moo;
 extends 'Printer::ESCPOS::Profiles::Generic';
 with 'Printer::ESCPOS::Roles::Profile';
 use namespace::autoclean;
 
-no Moose;
+no Moo;
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -37,7 +37,7 @@ Printer::ESCPOS::Profiles::SinocanPSeries - Sinocan P Series Profile for Printer
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 AUTHOR
 
