@@ -13,12 +13,12 @@ package Printer::ESCPOS::Roles::Connection;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 
 use 5.010;
-use Moose::Role;
+use Moo::Role;
 
 has _buffer => (
     is      => 'rw',
@@ -66,7 +66,7 @@ Printer::ESCPOS::Roles::Connection - Role for Connection Classes for L<Printer::
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 METHODS
 
