@@ -13,11 +13,11 @@ package Printer::ESCPOS::Roles::Profile;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 # Dependencies
 use 5.010;
-use Moose::Role;
+use Moo::Role;
 requires 'init';
 
 
@@ -29,7 +29,6 @@ has driver => (
 
 has usePrintMode => (
     is      => 'rw',
-    isa     => 'Bool',
     default => '0',
 );
 
@@ -42,28 +41,24 @@ has fontStyle => (
 
 has emphasizedStatus => (
     is      => 'rw',
-    isa     => 'Bool',
     default => 0,
 );
 
 
 has heightStatus => (
     is      => 'rw',
-    isa     => 'Int',
     default => 0,
 );
 
 
 has widthStatus => (
     is      => 'rw',
-    isa     => 'Int',
     default => 0,
 );
 
 
 has underlineStatus => (
     is      => 'rw',
-    isa     => 'Int',
     default => 0,
 );
 
@@ -103,7 +98,7 @@ Printer::ESCPOS::Roles::Profile - Role for all Printer Profiles for L<Printer::E
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 ATTRIBUTES
 
@@ -123,11 +118,11 @@ Set ESC-POS Font pass "a" "b" or "c". Note "c" is not supported across all print
 
 Set/unset emphasized property
 
-=head2 doubleHeightStatus
+=head2 heightStatus
 
 set unset double height property
 
-=head2 doubleWidthStatus
+=head2 widthStatus
 
 set unset double width property
 
